pub struct Buffer {
buf: Box<[MaybeUninit<u8>]>,
pos: usize,
filled: usize,
initialized: usize,
}Fields
buf: Box<[MaybeUninit<u8>]>pos: usizefilled: usizeinitialized: usizeImplementations
Sourceimpl Buffer
impl Buffer
pub fn with_capacity(capacity: usize) -> Self
pub fn try_with_capacity(capacity: usize) -> Result<Self>
pub fn buffer(&self) -> &[u8] ⓘ
pub fn capacity(&self) -> usize
pub fn filled(&self) -> usize
pub fn pos(&self) -> usize
pub fn discard_buffer(&mut self)
pub fn consume(&mut self, amt: usize)
Sourcepub fn consume_with<V>(&mut self, amt: usize, visitor: V) -> bool
pub fn consume_with<V>(&mut self, amt: usize, visitor: V) -> bool
If there are amt bytes available in the buffer, pass a slice containing those bytes to
visitor and return true. If there are not enough bytes available, return false.
pub fn unconsume(&mut self, amt: usize)
Sourcepub fn read_more(&mut self, reader: impl Read) -> Result<usize>
pub fn read_more(&mut self, reader: impl Read) -> Result<usize>
Read more bytes into the buffer without discarding any of its contents
pub fn fill_buf(&mut self, reader: impl Read) -> Result<&[u8]>